==> cycle_1.0.0.zip: cycle/doc/cycle.R <==
###################################################
### chunk number 1: 
###################################################
  library(cycle) 


###################################################
### chunk number 2: 
###################################################
set.seed(1)


###################################################
### chunk number 3: 
###################################################
data(yeast)
  yeast <- yeast[1:200,]


###################################################
### chunk number 4: 
###################################################
yeast <- filter.NA(yeast, thres=0.25)


###################################################
### chunk number 5: 
###################################################
yeast <- fill.NA(yeast,mode="mean")


###################################################
### chunk number 6: 
###################################################
yeast <- standardise(yeast)


###################################################
### chunk number 7: 
###################################################
auto.corr <- 0
for (i in 2:dim(exprs(yeast))[[2]]){
 auto.corr[i] <- cor(exprs(yeast)[,i-1],exprs(yeast)[,i])
 }
auto.corr 


###################################################
### chunk number 8: 
###################################################
T.yeast <- 85  


###################################################
### chunk number 9: 
###################################################
times.yeast <-  pData(yeast)$time 
times.yeast


###################################################
### chunk number 10: 
###################################################
NN <- 100 


###################################################
### chunk number 11: 
###################################################
fdr.rr <- fdrfourier(eset=yeast,T=T.yeast,times=times.yeast,background.model="rr",N=NN,progress=FALSE)


###################################################
### chunk number 12: 
###################################################
fdr.ar1 <- fdrfourier(eset=yeast,T=T.yeast,times=times.yeast,background.model="ar1",N=NN,progress=FALSE)


###################################################
### chunk number 13: 
###################################################
sum(fdr.rr$fdr < 0.25) 
sum(fdr.ar1$fdr < 0.25)


###################################################
### chunk number 14: 
###################################################
fdr.ar1$fdr[which(fdr.ar1$fdr < 0.25)]

==> cycle_1.4.0.zip: cycle/doc/cycle.R <==
###################################################
### chunk number 1: 
###################################################
#line 40 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpn65eJB/R.INSTALL2a0f4188/cycle/inst/doc/cycle.Rnw"
  library(cycle) 


###################################################
### chunk number 2: 
###################################################
#line 44 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpn65eJB/R.INSTALL2a0f4188/cycle/inst/doc/cycle.Rnw"
set.seed(1)


###################################################
### chunk number 3: 
###################################################
#line 54 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpn65eJB/R.INSTALL2a0f4188/cycle/inst/doc/cycle.Rnw"
data(yeast)
  yeast <- yeast[1:200,]


###################################################
### chunk number 4: 
###################################################
#line 64 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpn65eJB/R.INSTALL2a0f4188/cycle/inst/doc/cycle.Rnw"
yeast <- filter.NA(yeast, thres=0.25)


###################################################
### chunk number 5: 
###################################################
#line 74 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpn65eJB/R.INSTALL2a0f4188/cycle/inst/doc/cycle.Rnw"
yeast <- fill.NA(yeast,mode="mean")


###################################################
### chunk number 6: 
###################################################
#line 86 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpn65eJB/R.INSTALL2a0f4188/cycle/inst/doc/cycle.Rnw"
yeast <- standardise(yeast)


###################################################
### chunk number 7: 
###################################################
#line 101 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpn65eJB/R.INSTALL2a0f4188/cycle/inst/doc/cycle.Rnw"
auto.corr <- 0
for (i in 2:dim(exprs(yeast))[[2]]){
 auto.corr[i] <- cor(exprs(yeast)[,i-1],exprs(yeast)[,i])
 }
auto.corr 


###################################################
### chunk number 8: 
###################################################
#line 126 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpn65eJB/R.INSTALL2a0f4188/cycle/inst/doc/cycle.Rnw"
T.yeast <- 85  


###################################################
### chunk number 9: 
###################################################
#line 133 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpn65eJB/R.INSTALL2a0f4188/cycle/inst/doc/cycle.Rnw"
times.yeast <-  pData(yeast)$time 
times.yeast


###################################################
### chunk number 10: 
###################################################
#line 146 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpn65eJB/R.INSTALL2a0f4188/cycle/inst/doc/cycle.Rnw"
NN <- 100 


###################################################
### chunk number 11: 
###################################################
#line 156 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpn65eJB/R.INSTALL2a0f4188/cycle/inst/doc/cycle.Rnw"
fdr.rr <- fdrfourier(eset=yeast,T=T.yeast,times=times.yeast,background.model="rr",N=NN,progress=FALSE)


###################################################
### chunk number 12: 
###################################################
#line 166 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpn65eJB/R.INSTALL2a0f4188/cycle/inst/doc/cycle.Rnw"
fdr.ar1 <- fdrfourier(eset=yeast,T=T.yeast,times=times.yeast,background.model="ar1",N=NN,progress=FALSE)


###################################################
### chunk number 13: 
###################################################
#line 179 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpn65eJB/R.INSTALL2a0f4188/cycle/inst/doc/cycle.Rnw"
sum(fdr.rr$fdr < 0.25) 
sum(fdr.ar1$fdr < 0.25)


###################################################
### chunk number 14: 
###################################################
#line 187 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpn65eJB/R.INSTALL2a0f4188/cycle/inst/doc/cycle.Rnw"
fdr.ar1$fdr[which(fdr.ar1$fdr < 0.25)]
